package com.sun.java.swing.plaf.windows;

import javax.swing.border.Border;
import javax.swing.table.TableColumn;
import java.awt.Dimension;
import sun.swing.SwingUtilities2;
import java.awt.Graphics;
import javax.swing.SortOrder;
import javax.swing.Icon;
import java.awt.Insets;
import javax.swing.UIManager;
import javax.swing.border.EmptyBorder;
import java.awt.Component;
import javax.swing.JTable;
import sun.swing.table.DefaultTableCellHeaderRenderer;
import javax.swing.table.JTableHeader;
import javax.swing.plaf.UIResource;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.table.TableCellRenderer;
import javax.swing.plaf.basic.BasicTableHeaderUI;

public class WindowsTableHeaderUI extends BasicTableHeaderUI
{
    private TableCellRenderer originalHeaderRenderer;
    
    public WindowsTableHeaderUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new WindowsTableHeaderUI();
    }
    
    @Override
    public void installUI(JComponent c) {
        super.installUI(c);
        if (XPStyle.getXP() != null) {
            this.originalHeaderRenderer = this.header.getDefaultRenderer();
            if ((this.originalHeaderRenderer instanceof UIResource)) {
                this.header.setDefaultRenderer(new WindowsTableHeaderUI.XPDefaultRenderer());
            }
        }
    }
    
    @Override
    public void uninstallUI(JComponent c) {
        if ((this.header.getDefaultRenderer() instanceof WindowsTableHeaderUI.XPDefaultRenderer)) {
            this.header.setDefaultRenderer(this.originalHeaderRenderer);
        }
        super.uninstallUI(c);
    }
    
    @Override
    protected void rolloverColumnUpdated(int column, int column2) {
        if (XPStyle.getXP() != null) {
            this.header.repaint(this.header.getHeaderRect(column));
            this.header.repaint(this.header.getHeaderRect(column2));
        }
    }
    
    static int access$000(WindowsTableHeaderUI windowsTableHeaderUI) {
        return windowsTableHeaderUI.getRolloverColumn();
    }
    
    private class XPDefaultRenderer extends DefaultTableCellHeaderRenderer
    {
        XPStyle.Skin skin;
        boolean isSelected;
        boolean hasFocus;
        boolean hasRollover;
        int column;
        
        XPDefaultRenderer() {
            this.setHorizontalAlignment(10);
        }
        
        @Override
        public Component getTableCellRendererComponent(JTable table, Object value, boolean b, boolean b2, int row, int column) {
            super.getTableCellRendererComponent(table, value, b, b2, row, column);
            this.isSelected = b;
            this.hasFocus = b2;
            this.column = column;
            this.hasRollover = (column == WindowsTableHeaderUI.access$000(WindowsTableHeaderUI.this));
            if (this.skin == null) {
                XPStyle xp = XPStyle.getXP();
                this.skin = ((xp != null) ? xp.getSkin(WindowsTableHeaderUI.this.header, TMSchema.Part.HP_HEADERITEM) : null);
            }
            Insets insets = (this.skin != null) ? this.skin.getContentMargin() : null;
            int top = 0;
            int left = 0;
            int bottom = 0;
            int right = 0;
            if (insets != null) {
                top = insets.top;
                left = insets.left;
                bottom = insets.bottom;
                right = insets.right;
            }
            left += 5;
            bottom += 4;
            right += 5;
            Icon icon;
            Object border;
            if (WindowsLookAndFeel.isOnVista() && ((icon = this.getIcon()) instanceof UIResource || icon == null)) {
                ++top;
                this.setIcon(null);
                Icon icon2 = null;
                SortOrder columnSortOrder = DefaultTableCellHeaderRenderer.getColumnSortOrder(table, column);
                if (columnSortOrder != null) {
                    switch (columnSortOrder) {
                        case ASCENDING: {
                            icon2 = UIManager.getIcon("Table.ascendingSortIcon");
                            break;
                        }
                        case DESCENDING: {
                            icon2 = UIManager.getIcon("Table.descendingSortIcon");
                            break;
                        }
                    }
                }
                if (icon2 != null) {
                    border = new WindowsTableHeaderUI.IconBorder(icon2, top, left, icon2.getIconHeight(), right);
                }
                else {
                    Icon icon3 = UIManager.getIcon("Table.ascendingSortIcon");
                    int n = (icon3 != null) ? icon3.getIconHeight() : 0;
                    if (n != 0) {
                        bottom = n;
                    }
                    border = new EmptyBorder(n + top, left, bottom, right);
                }
            }
            else {
                top += 3;
                border = new EmptyBorder(top, left, bottom, right);
            }
            this.setBorder(border);
            return this;
        }
        
        @Override
        public void paint(Graphics g) {
            Dimension size = this.getSize();
            TMSchema.State state = TMSchema.State.NORMAL;
            TableColumn draggedColumn = WindowsTableHeaderUI.this.header.getDraggedColumn();
            if (draggedColumn != null && this.column == SwingUtilities2.convertColumnIndexToView(WindowsTableHeaderUI.this.header.getColumnModel(), draggedColumn.getModelIndex())) {
                state = TMSchema.State.PRESSED;
            }
            else if (this.isSelected || this.hasFocus || this.hasRollover) {
                state = TMSchema.State.HOT;
            }
            if (WindowsLookAndFeel.isOnVista()) {
                SortOrder columnSortOrder = DefaultTableCellHeaderRenderer.getColumnSortOrder(WindowsTableHeaderUI.this.header.getTable(), this.column);
                if (columnSortOrder != null) {
                    switch (columnSortOrder) {
                        case ASCENDING:
                        case DESCENDING: {
                            switch (state) {
                                case NORMAL: {
                                    state = TMSchema.State.SORTEDNORMAL;
                                    break;
                                }
                                case PRESSED: {
                                    state = TMSchema.State.SORTEDPRESSED;
                                    break;
                                }
                                case HOT: {
                                    state = TMSchema.State.SORTEDHOT;
                                    break;
                                }
                            }
                        }
                    }
                }
            }
            this.skin.paintSkin(g, 0, 0, size.width - 1, size.height - 1, state);
            super.paint(g);
        }
    }
    
    private static class IconBorder implements Border, UIResource
    {
        private final Icon icon;
        private final int top;
        private final int left;
        private final int bottom;
        private final int right;
        
        public IconBorder(Icon icon, int top, int left, int bottom, int right) {
            this.icon = icon;
            this.top = top;
            this.left = left;
            this.bottom = bottom;
            this.right = right;
        }
        
        @Override
        public Insets getBorderInsets(Component component) {
            return new Insets(this.icon.getIconHeight() + this.top, this.left, this.bottom, this.right);
        }
        
        @Override
        public boolean isBorderOpaque() {
            return false;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            this.icon.paintIcon(component, graphics, n + this.left + (n3 - this.left - this.right - this.icon.getIconWidth()) / 2, n2 + this.top);
        }
    }
}
